#!/bin/bash
# Configure Stormux
# A script to configure the system for new users.
#
# Copyright 2020, Storm Dragon, <storm_dragon@linux-a11y.org>
#
# This is free software; you can redistribute it and/or modify it under the
# terms of the GNU General Public License as published by the Free
# Software Foundation; either version 3, or (at your option) any later
# version.
#
# This software is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this package; see the file COPYING.  If not, write to the Free
# Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
# 02110-1301, USA.
#
#--code--


# Include functions common to all operations
source .includes/functions.sh
# Include the dialog based UI
source .includes/ui.sh

# Make sure basic xdg directory structure is in place:
if [[ ! -d ~/Desktop ]]; then
    xdg-user-dirs-update
fi

# Check for possible resize
diskSource="$(df --output='source' / | tail -1)"
diskSize="$(df -h --output='size' / | tail -1 | tr -cd '[:digit:].')"
diskSize=${diskSize%.*}
if [[ $diskSize -le 5 ]]; then
    if [[ "$(yesno "$diskSource is only $diskSize gigs, which means it probably needs to be resized. Would you like to do this now?")" == "Yes" ]]; then
        sudo growpartfs $diskSource
    fi
fi

while [[ "$choice" != "Exit" ]]; do
    case "$choice" in
        "Change username")
            ./.includes/chuser.sh $(inputbox "Please enter the new username, letters, dashes, and underscores only.")
            restart
        ;;
        "Configure internet")
            /usr/bin/nmtui-connect
        ;;
        "Install Mate Desktop")
            source .includes/gui.sh mate
        ;;
        "Install Ratpoison Windowmanager")
            source .includes/gui.sh ratpoison
        ;;
        "Screen reader")
            source .includes/screenreader.sh
        ;;
        "Set up gaming")
            source .includes/gaming.sh
        ;;
    esac
    choice="$(menulist \
        "Change username" \
        "Configure internet" \
        "Install Mate Desktop" \
        "Install Ratpoison Windowmanager" \
        "Screen reader" \
        "Set up gaming" \
        "Exit" \
    )"
done

exit 0
